@@ -6,7 +6,7 @@ from scipy.stats import poisson, norm, chi2
 from scipy.linalg import solve_triangular
 from ..io.file import FileIOMixin
 from .format import ParameterFormatter, CostFunctionFormatter
-from ..util import log_determinant
+from ..util import cholesky_decomposition, log_determinant
 
 if six.PY2:
     from funcsigs import signature
@@ -105,6 +105,7 @@ class CostFunction(FileIOMixin, object):
                 self._arg_names += ["total_cov_mat_log_determinant"]
             self._arg_count += 1
 
+        self._errors_valid = True
         self._needs_errors = True
         self._is_chi2 = False
         self._saturated = False
@@ -195,6 +196,10 @@ class CostFunction(FileIOMixin, object):
         """Optimized version of cost function that uses pointwise errors, can be None."""
         return None
 
+    @property
+    def errors_valid(self):
+        return self._errors_valid
+
     def goodness_of_fit(self, *args):
         """How well the model agrees with the data."""
         try:
@@ -297,7 +302,7 @@ class CostFunction_Chi2(CostFunction):
         self._formatter.latex_name = "\\chi^2"
         self._formatter.name = "chi2"
         self._formatter.description = _cost_function_description
-        self._needs_errors = errors_to_use is not None
+        self._errors_valid = self._needs_errors = errors_to_use is not None
         self._is_chi2 = True
         self._saturated = True
         self._kafe2go_identifier = self.name
@@ -649,7 +654,7 @@ class CostFunction_GaussApproximation(CostFunction):
         self._saturated = True
         self._kafe2go_identifier = self.name
 
-    def gaussian_approximation_covariance(self, data, model, total_cov_mat_cholesky):
+    def gaussian_approximation_covariance(self, data, model, total_cov_mat):
         r"""A least-squares cost function calculated from (`y`) data and model values,
         considering the covariance matrix of the (`y`) measurements.
         The cost function value can be calculated as follows:
@@ -673,12 +678,11 @@ class CostFunction_GaussApproximation(CostFunction):
 
         :param data: measurement data :math:`{\bf d}`
         :param model: model predictions :math:`{\bf m}`
-        :param total_cov_mat_cholesky: Cholesky decomposition  of the total covariance matrix
-            :math:`{\bf L}` with :math:`{\bf L}^\top {\bf L} = {\bf V}`
+        :param total_cov_mat: The total covariance matrix :math:`{\bf V}`
 
         :return: cost function value
         """
-        _cholesky = total_cov_mat_cholesky + np.diag(np.sqrt(model))
+        _cholesky = cholesky_decomposition(total_cov_mat + np.diag(model))
         _residuals = model - data
         try:
             _x = solve_triangular(_cholesky, _residuals, lower=True)
@@ -756,7 +760,7 @@ STRING_TO_COST_FUNCTION = {
     'chi_2': (CostFunction_Chi2, {}),
     'chisquared': (CostFunction_Chi2, {}),
     'chi_squared': (CostFunction_Chi2, {}),
-    'chi2_no_errors': (CostFunction_Chi2, {"errors_to_use": None}),
+    'chi2_no_errors': (CostFunction_Chi2, {"errors_to_use": None, "add_determinant_cost": False}),
     'chi2_pointwise': (CostFunction_Chi2, {"errors_to_use": "pointwise"}),
     'chi2_pointwise_errors': (CostFunction_Chi2, {"errors_to_use": "pointwise"}),
     'chi2_covariance': (CostFunction_Chi2, {"errors_to_use": "covariance"}),
