@@ -6,8 +6,10 @@ import textwrap
 import warnings
 import itertools
 import matplotlib as mpl
-import sys
+import os
+from collections.abc import Iterable
 
+from .format import ParameterFormatter
 from ..multi.fit import MultiFit
 from ...config import kc, ConfigError, kafe2_rc
 
@@ -20,9 +22,6 @@ from matplotlib import rc_context
 __all__ = ["PlotAdapterBase", "Plot", "PlotAdapterException", "PlotFigureException",
            "kc_plot_style"]
 
-_python_version = sys.version_info[0]
-_float_template = ".3g" if _python_version == 2 else "#.3g"
-
 
 def kc_plot_style(data_type, subplot_key, property_key):
     try:
@@ -196,6 +195,8 @@ class PlotAdapterBase(object):
                 label = None
             _axis_labels.append(label)
         self._axis_labels = _axis_labels
+        _x_ticks = fit_object._get_default_x_ticks()
+        self._ticks = [_x_ticks, []]
 
         # specification of subplots for which this adapter provided plot routines
         self._subplots = None
@@ -269,7 +270,12 @@ class PlotAdapterBase(object):
         """Resolve the keyword arguments passed to the plot method."""
         _subplots = self._get_subplots()
 
-        _explicit_kwargs = _subplots[plot_type].get('plot_method_keywords', {})
+        try:
+            _subplot = _subplots[plot_type]
+        except KeyError as exc:
+            raise ValueError(
+                f"Unknown subplot: {plot_type} . Available: {list(_subplots.keys())}") from exc
+        _explicit_kwargs = _subplot.get('plot_method_keywords', {})
 
         # get static kwargs
         _plot_style_as = _subplots[plot_type].get('plot_style_as', plot_type)
@@ -560,6 +566,22 @@ class PlotAdapterBase(object):
             label = None
         self._axis_labels[1] = label
 
+    @property
+    def x_ticks(self):
+        return self._ticks[0]
+
+    @x_ticks.setter
+    def x_ticks(self, ticks):
+        self._ticks[0] = ticks
+
+    @property
+    def y_ticks(self):
+        return self._ticks[1]
+
+    @y_ticks.setter
+    def y_ticks(self, ticks):
+        self._ticks[1] = ticks
+
     @abc.abstractmethod
     def plot_data(self, target_axes, **kwargs):
         """Method called by the main plot routine to plot the data points to a specified
@@ -658,8 +680,8 @@ class Plot(object):
         {model_function}
         {parameters}
             $\\hookrightarrow${fit_quality}
-            $\\hookrightarrow \\chi^2 \\, \\mathrm{{probability =}}${chi2_probability:%s}
-    """ % _float_template)
+            $\\hookrightarrow \\chi^2 \\, \\mathrm{{probability =}}${chi2_probability}
+    """)
     FIT_INFO_STRING_FORMAT_SATURATED = textwrap.dedent("""\
         {model_function}
         {parameters}
@@ -846,7 +868,7 @@ class Plot(object):
                 '    ' + _pf.get_formatted(
                     with_name=True,
                     with_value=True,
-                    with_errors=True,
+                    with_errors=plot_adapter._fit.errors_valid,
                     asymmetric_error=asymmetric_parameter_errors,
                     format_as_latex=format_as_latex
                 )
@@ -854,7 +876,7 @@ class Plot(object):
             ])
         )
         # _gof_value is None for UnbinnedFit and some user-defined cost functions.
-        if _gof_value is not None:
+        if plot_adapter._fit.errors_valid and _gof_value is not None:
             _info_format_dict["fit_quality"] = _cost_func.formatter.get_formatted(
                 value=_gof_value,
                 with_name=True,
@@ -865,7 +887,9 @@ class Plot(object):
             )
             if plot_adapter._fit._cost_function.is_chi2:
                 _info_format_string = self.FIT_INFO_STRING_FORMAT_CHI2
-                _info_format_dict["chi2_probability"] = plot_adapter._fit.chi2_probability
+                _chi2_pf = ParameterFormatter("chi2", plot_adapter._fit.chi2_probability)
+                _info_format_dict["chi2_probability"] = _chi2_pf.get_formatted(
+                    n_significant_digits=3, format_as_latex=format_as_latex)
             elif plot_adapter._fit._cost_function.saturated:
                 _info_format_string = self.FIT_INFO_STRING_FORMAT_SATURATED
             else:
@@ -894,9 +918,11 @@ class Plot(object):
             _multi_info_dict = dict()
             if _multi_cost_function.is_chi2:
                 _template = "    $\\hookrightarrow$ global {fit_quality}\n"
-                _multi_info_dict["chi2_probability"] = self._multifit.chi2_probability
+                _chi2_pf = ParameterFormatter("chi2", self._multifit.chi2_probability)
+                _multi_info_dict["chi2_probability"] = _chi2_pf.get_formatted(
+                    n_significant_digits=3, format_as_latex=format_as_latex)
                 _template += "    $\\hookrightarrow$ global $\\chi^2 \\, \\mathrm{{probability}} " \
-                             "= {chi2_probability:%s}$" % _float_template
+                             "= ${chi2_probability}"
             elif _multi_cost_function.saturated:
                 _template = "    $\\hookrightarrow$ global cost / ndf = {fit_quality}\n"
             else:
@@ -1041,6 +1067,19 @@ class Plot(object):
             _ax.set_xlabel(', '.join(filter(None, [label for label in _seen_x_labels])))
             _ax.set_ylabel(', '.join(filter(None, [label for label in _seen_y_labels])))
 
+            _adapter = _axes_dict['plots'][0]['adapter']
+            _x_ticks = _adapter.x_ticks
+            _y_ticks = _adapter.y_ticks
+
+            if len(_x_ticks) > 0:
+                if isinstance(_x_ticks[0], str):
+                    _ax.set_xticks(np.arange(len(_x_ticks)), labels=_x_ticks)
+                else:
+                    _ax.set_xticks(_x_ticks)
+
+            if len(_y_ticks) > 0:
+                _ax.set_yticks(_y_ticks)
+
         # hide x tick labels in all but the lowest axes
         for _key in axes_keys[:-1]:
             self._current_axes[_key].set_xlabel(None)
@@ -1119,6 +1158,20 @@ class Plot(object):
                                       .format(len(var), len(_adapters)))
         return var
 
+    def _repeat_ticks(self, ticks):
+        try:
+            iter(ticks)
+        except TypeError:
+            raise TypeError(f"Ticks have to be iterable but received {ticks}")
+        try:
+            iter(ticks[0])
+            _ticks_is_1d_iter = isinstance(ticks[0], str)
+        except TypeError:
+            _ticks_is_1d_iter = True
+        if _ticks_is_1d_iter:
+            ticks = itertools.repeat(ticks, len(self._get_plot_adapters()))
+        return ticks
+
     @property
     def x_scale(self):
         """The x-scale for each fit used for creating the support values when plotting and axis
@@ -1176,7 +1229,31 @@ class Plot(object):
         for _l, adapter in zip(label, self._get_plot_adapters()):
             adapter.y_label = _l
 
-    # -- public methods
+    @property
+    def x_ticks(self):
+        return [_adapter.x_ticks for _adapter in self._get_plot_adapters()]
+
+    @x_ticks.setter
+    def x_ticks(self, ticks):
+        for _t, adapter in zip(self._repeat_ticks(ticks), self._get_plot_adapters()):
+            adapter.x_ticks = _t
+
+    @property
+    def y_ticks(self):
+        return [_adapter.y_ticks for _adapter in self._get_plot_adapters()]
+
+    @y_ticks.setter
+    def y_ticks(self, ticks):
+        for _t, adapter in zip(self._repeat_ticks(ticks), self._get_plot_adapters()):
+            adapter.y_ticks = _t
+
+    # public methods
+
+    @staticmethod
+    def show(*args, **kwargs):
+        """Convenience wrapper for matplotlib.pyplot.show()"""
+        plt.show(*args, **kwargs)
+
 
     def plot(self, legend=True, fit_info=True, asymmetric_parameter_errors=False,
              ratio=False, ratio_range=None, ratio_height_share=0.25,
@@ -1533,3 +1610,44 @@ class Plot(object):
             ]
 
         return self.set_keywords(plot_type, _dicts)
+
+    def save(self, fname=None, figures='all', *args, **kwargs):
+        """
+        Saves the plot figures to files.
+        args and kwargs are passed on to matplotlib.Figure.savefig() .
+
+        :param fname: Output file name(s), defaults to fit.png or fit_0.png, fit_1.png, ...
+        :type fname: None or str or iterable of str.
+        :param figures: Which figures to save.
+        :type figures: 'all' or int or iterable of int
+        """
+        if figures == 'all':
+            _figure_indices = range(len(self._figure_dicts))
+        elif isinstance(figures, int):
+            _figure_indices = [figures]
+        _file_name_list = fname
+        if fname is None:
+            if len(self._figure_dicts) == 1:
+                _file_name_list = ["fit.png"]
+            else:
+                _file_name_list = [f'fit_{_i}.png' for _i in _figure_indices]
+        elif isinstance(fname, str):
+            if len(_figure_indices) == 1:
+                _file_name_list = [fname]
+            else:
+                name, extension = os.path.splitext(fname)
+                _file_name_list = [f'{name}_{_i}{extension}' for _i in _figure_indices]
+        elif isinstance(fname, Iterable):
+            _file_name_list = fname
+        else:
+            raise ValueError(
+                "fname must be either None, a string, or an iterable, but received type "
+                f"{type(fname)}"
+            )
+        if len(_file_name_list) != len(_figure_indices):
+            raise ValueError(
+                f'Received {len(_file_name_list)} file names for {len(_figure_indices)} figures.'
+                'Must be the same!'
+            )
+        for _figure_index, _file_name in zip(_figure_indices, _file_name_list):
+            self._figure_dicts[_figure_index]['figure'].savefig(_file_name, *args, **kwargs)
