@@ -2,7 +2,9 @@ import numpy as np
 import six
 import sys
 import matplotlib as mpl
+import os
 
+from collections.abc import Iterable
 from ...config import kafe2_rc
 from ...core.confidence import ConfidenceLevel
 from .._base import FitBase
@@ -252,17 +254,37 @@ class ContoursProfiler(object):
 
     # - get numeric profiles/contours
 
-    def get_profile(self, parameter):
+    @staticmethod
+    def show(*args, **kwargs):
+        """Convenience wrapper for matplotlib.pyplot.show()"""
+        plt.show(*args, **kwargs)
+
+
+    def get_profile(self, parameter, points=None, bound=None, subtract_min=None):
         """
         Calculate and return a profile of the cost function in a parameter.
 
-        :param parameter: name of the parameter to profile in
+        :param parameter: name of the parameter to profile (referred to as *x* here).
         :type parameter: str
+        :param points: number of equidistant points to use as *x* values
+        :type points: int
+        :param bound: parameter region for the profile. A single value is interpreted as a sigma
+            value for an interval symmetric around the cost function minimum. A tuple of two values
+            is interpreted as the bounds of an arbitrary *x* interval to be profiled.
+        :type bound: int or tuple of int
+        :subtract_min: if the minimal cost function value should be subtracted from the profile
+            *y* values.
+        :type subtract_min: bool
         :return: two-dimensional array of *x* (parameter) values and *y* (cost function) values
         :rtype: two-dimensional array of float
         """
-        _kwargs = dict(bins=self._profile_kwargs['points'], bound=self._profile_kwargs['bound'],
-                       args=None, subtract_min=self._profile_kwargs['subtract_min'])
+        if bound is None:
+            bound = 2
+        if points is None:
+            points = self._profile_kwargs['points']
+        if subtract_min is None:
+            subtract_min = self._profile_kwargs['subtract_min']
+        _kwargs = dict(bins=points, bound=bound, args=None, subtract_min=subtract_min)
         self._fit._check_dynamic_error_compatibility()
         return self._fit._fitter.profile(parameter, **_kwargs)  # TODO fix for single fit inside multifit
 
@@ -774,3 +796,48 @@ class ContoursProfiler(object):
             _maybe_set_tight_layout(_fig)
 
             return _fig
+
+    def save(self, fname=None, figures='all', *args, **kwargs):
+        """
+        Saves the profile figures to files.
+        args and kwargs are passed on to matplotlib.Figure.savefig() .
+
+        :param fname: Output file name(s), defaults to profile.png or profile_0.png,
+            profile_1.png, ...
+        :type fname: None or str or iterable of str.
+        :param figures: Which figures to save.
+        :type figures: 'all' or int or iterable of int
+        """
+        if figures == 'all':
+            _figure_indices = range(len(self._figures))
+        elif isinstance(figures, int):
+            _figure_indices = [figures]
+        else:
+            raise TypeError(f"figures must be either 'all', int or iterable of int, but received type"
+                            f"{type(figures)}")
+        _file_name_list = fname
+        if fname is None:
+            if len(self._figures) == 1:
+                _file_name_list = ['profile.png']
+            else:
+                _file_name_list = [f'profile_{_i}.png' for _i in _figure_indices]
+        elif isinstance(fname, str):
+            if len(_figure_indices) == 1:
+                _file_name_list = [fname]
+            else:
+                name, extension = os.path.splitext(fname)
+                _file_name_list = [f'{name}_{_i}{extension}' for _i in _figure_indices]
+        elif isinstance(fname, Iterable):
+            _file_name_list = fname
+        else:
+            raise ValueError(
+                "fname must be either None, a string, or an iterable, but received type "
+                f"{type(fname)}"
+            )
+        if len(_file_name_list) != len(_figure_indices):
+            raise ValueError(
+                f'Received {len(_file_name_list)} file names for {len(_figure_indices)} figures.'
+                'Must be the same!'
+            )
+        for _figure_index, _file_name in zip(_figure_indices, _file_name_list):
+            self._figures[_figure_index].savefig(_file_name, *args, **kwargs)
