@@ -1,4 +1,5 @@
-from .._base import CostFunction_Chi2, CostFunction_NegLogLikelihood, CostFunctionException
+from .._base import CostFunction_Chi2, CostFunction_NegLogLikelihood, CostFunctionException, \
+    CostFunction_GaussApproximation
 
 __all__ = [
     "XYCostFunction_Chi2",
@@ -55,7 +56,7 @@ class XYCostFunction_NegLogLikelihood(CostFunction_NegLogLikelihood):
             data_point_distribution=data_point_distribution, ratio=ratio)
 
 
-class XYCostFunction_GaussApproximation(CostFunction_Chi2):
+class XYCostFunction_GaussApproximation(CostFunction_GaussApproximation):
     def __init__(
             self, errors_to_use='covariance', axes_to_use='xy',
             add_constraint_cost=True, add_determinant_cost=True):
@@ -96,7 +97,7 @@ STRING_TO_COST_FUNCTION = {
     'chi_2': (XYCostFunction_Chi2, {}),
     'chisquared': (XYCostFunction_Chi2, {}),
     'chi_squared': (XYCostFunction_Chi2, {}),
-    'chi2_no_errors': (XYCostFunction_Chi2, {"errors_to_use": None}),
+    'chi2_no_errors': (XYCostFunction_Chi2, {"errors_to_use": None, "add_determinant_cost": False}),
     'chi2_pointwise': (XYCostFunction_Chi2, {"errors_to_use": "pointwise"}),
     'chi2_pointwise_errors': (XYCostFunction_Chi2, {"errors_to_use": "pointwise"}),
     'chi2_covariance': (XYCostFunction_Chi2, {"errors_to_use": "covariance"}),
