@@ -1,5 +1,5 @@
 import abc
-import unittest2 as unittest
+import unittest
 import numpy as np
 import six
 
@@ -341,7 +341,7 @@ class TestIndexedFitBasicInterface(AbstractTestFit, unittest.TestCase):
         ], dynamic_error_algorithm="nonlinear")
         _fit_data_err.do_fit()
         _fit_model_err.do_fit()
-        self._assert_fit_results_equal(_fit_data_err, _fit_model_err, rtol=3e-2)
+        self._assert_fit_results_equal(_fit_data_err, _fit_model_err, rtol=1e-2, atol=2e-2)
 
     def test_relative_model_error_iterative(self):
         _fit_data_err = self._get_fit(errors=[
@@ -356,6 +356,16 @@ class TestIndexedFitBasicInterface(AbstractTestFit, unittest.TestCase):
         _fit_model_err.do_fit()
         self._assert_fit_results_equal(_fit_data_err, _fit_model_err, rtol=1e-2)
 
+    def test_fit_scalar_model_function(self):
+        def _model_function(a):
+            return a
+
+        _fit = IndexedFit([1, 2], _model_function)
+        _fit.add_error(1.0)
+        _fit.do_fit()
+        self.assertAlmostEqual(_fit.parameter_values[0], 1.5)
+        _fit.report()
+
 
 class TestIndexedFitWithSimpleErrors(AbstractTestFit, unittest.TestCase):
 
