@@ -1,5 +1,5 @@
 import abc
-import unittest2 as unittest
+import unittest
 import numpy as np
 import six
 
@@ -61,16 +61,15 @@ class TestUnbinnedFitBasicInterface(AbstractTestFit, unittest.TestCase):
 
         # helper dict with all reference property values
         self._ref_prop_dict = dict(
-            parameter_values=self._ref_initial_pars,
-            poi_values=self._ref_initial_pars,
-
-            data=self._ref_data,
-            model=self._ref_initial_model,
-            cost_function_value=self._ref_initial_cost,
-            poi_names=('tau', 'fbg'),
             did_fit=False,
             model_count=1,
 
+            parameter_values=self._ref_initial_pars,
+            parameter_names=('tau', 'fbg'),
+            cost_function_value=self._ref_initial_cost,
+
+            data=self._ref_data,
+            model=self._ref_initial_model,
         )
 
     def _get_fit(self, model_density_function=None, cost_function=None):
@@ -106,7 +105,6 @@ class TestUnbinnedFitBasicInterface(AbstractTestFit, unittest.TestCase):
             dict(
                 self._ref_prop_dict,
                 parameter_values=self._nominal_fit_result_pars,
-                poi_values=self._nominal_fit_result_pars,
                 model=self._nominal_fit_result_model,
                 did_fit=True,
                 cost_function_value=np.float64(self._nominal_fit_result_cost),
@@ -155,7 +153,6 @@ class TestUnbinnedFitBasicInterface(AbstractTestFit, unittest.TestCase):
             dict(
                 data=_new_data,
                 parameter_values=np.array([1.64489992, 0.1225065]),
-                poi_values=np.array([1.64489992, 0.1225065]),
             ),
             rtol=1e-2
         )
@@ -253,3 +250,13 @@ class TestUnbinnedFitBasicInterface(AbstractTestFit, unittest.TestCase):
         _fit.do_fit()
         _fit.report(output_stream=_buffer)
         self.assertNotEqual(_buffer.getvalue(), "")
+
+    def test_fit_scalar_model_function(self):
+        def _model_function(x, a):
+            return a
+
+        _fit = UnbinnedFit([1.0, 2.0], _model_function)
+        _fit.limit_parameter("a", 0.001, 0.999)
+        _fit.do_fit()
+        self.assertAlmostEqual(_fit.parameter_values[0], 0.999)
+        _fit.report()
