@@ -1,5 +1,5 @@
 import abc
-import unittest2 as unittest
+import unittest
 import numpy as np
 import six
 
@@ -490,6 +490,17 @@ class TestXYFitBasicInterface(AbstractTestFit, unittest.TestCase):
         _fit_model_err.do_fit()
         self._assert_fit_results_equal(_fit_data_err, _fit_model_err, rtol=1e-2)
 
+    def test_fit_scalar_model_function(self):
+        def _model_function(x, a):
+            return a
+
+        _fit = XYFit([[0.0, 2.0], [1.0, 2.0]], _model_function)
+        _fit.add_error("y", 1.0)
+        _fit.do_fit()
+        self.assertAlmostEqual(_fit.parameter_values[0], 1.5)
+        _fit.report()
+
+
 
 class TestXYFitWithSimpleYErrors(AbstractTestFit, unittest.TestCase):
 
