@@ -2,8 +2,9 @@ import numpy as np
 from scipy.optimize import minimize
 
 
-def calculate_expected_fit_parameters_xy(x_data, y_data, model_function, y_error, initial_parameter_values,
-                                         x_error=None, model_function_derivative=None):
+def calculate_expected_fit_parameters_xy(
+        x_data, y_data, model_function, y_error, initial_parameter_values, x_error=None,
+        model_function_derivative=None, relative_model_y_error=False):
     x_data = np.array(x_data)
     y_data = np.array(y_data)
     y_error = np.array(y_error)
@@ -11,17 +12,24 @@ def calculate_expected_fit_parameters_xy(x_data, y_data, model_function, y_error
 
     def chi2(parameter_values):
         _residuals = y_data - model_function(x_data, *parameter_values)
-        return np.sum((_residuals / y_error) ** 2)
+        return np.sum((_residuals / y_error) ** 2) + np.sum(np.log(y_error ** 2))
 
-    def chi2_xy(parameter_values):
-        _residuals = y_data - model_function(x_data, *parameter_values)
-        _xy_error_squared = y_error ** 2 + (x_error * model_function_derivative(x_data, *parameter_values)) ** 2
-        return np.sum(_residuals ** 2 / _xy_error_squared)
+    def chi2_dynamic_error(parameter_values):
+        _model = model_function(x_data, *parameter_values)
+        _residuals = y_data - _model
+        _x_error = x_error * model_function_derivative(x_data, *parameter_values) \
+            if x_error is not None else 0
+        _x_error = 0
+        _y_error = y_error if not relative_model_y_error else y_error * _model
+        _xy_error_squared = _x_error ** 2 + _y_error ** 2
+        return np.sum(_residuals ** 2 / _xy_error_squared) + np.sum(np.log(_xy_error_squared))
 
     _result = minimize(fun=chi2, x0=initial_parameter_values)
-    if x_error is None:
+    print(1, _result.x)
+    if x_error is None and not relative_model_y_error:
         return _result.x
-    _result_2 = minimize(fun=chi2_xy, x0=_result.x)
+    _result_2 = minimize(fun=chi2_dynamic_error, x0=_result.x)
+    print(2, _result_2.x)
     return _result_2.x
 
 
